@@ -23,15 +23,17 @@
 #include <qstringlist.h>
 #include <qstring.h>
 #include <qcheckbox.h>
+//Added by qt3to4:
+#include <QShowEvent>
 
 /* OTHER INCLUDES */
 #include <kommanderwidget.h>
-#include "kommander_export.h"
+#include "kommanderwidgets_export.h"
 
 class QWidget;
 
 class QShowEvent;
-class KOMMANDER_EXPORT CheckBox : public QCheckBox, public KommanderWidget
+class KOMMANDERWIDGETS_EXPORT CheckBox : public QCheckBox, public KommanderWidget
 {
   Q_OBJECT
 
@@ -49,7 +51,8 @@ public:
   virtual QString populationText() const;
   virtual void setPopulationText(const QString&);
   
-  virtual QString handleDCOP(int function, const QStringList& args);
+  virtual QString handleDBUS(int function, const QStringList& args);
+  using KommanderWidget::handleDBUS;
   virtual bool isFunctionSupported(int function);
 public slots:
   virtual void setWidgetText(const QString&);
@@ -57,8 +60,10 @@ public slots:
 signals:
   void widgetOpened();
   void widgetTextChanged(const QString&);
+  void contextMenuRequested(int xpos, int ypos);
 protected:
-    void showEvent(QShowEvent *e);
+  void showEvent(QShowEvent *e);
+  void contextMenuEvent( QContextMenuEvent * e );
 private:
 };
 
